@@ -65,14 +65,15 @@ class JobServer ():
       # we also don't want to register with mPCC
       self.register = False
 
-    # Load Plugins. (plugins register job modules.)
-    self.load_plugins()
-
     # Authenticat to the Control Center and start a session
     print("mProv Job Server authenticating.")
     if not self.startSession():
         print("Error: Unable to log into mProv Control Center.",file=sys.stderr)
 
+
+    # Load Plugins. (plugins register job modules.)
+    self.load_plugins()
+
     # register the server.
     self.register_server()
 
@@ -219,10 +220,16 @@ class JobServer ():
     else:
       queryURL = self.mprovURL + 'jobs/?search=' + job_module
     response = self.session.get( queryURL )
-    if response.status_code == 400:
-        print("Error: Server returned error 400. Make sure your specified jobmodules exist.",file=sys.stderr)
+    if response.status_code <= 199 or response.status_code >=300:
+
+        print(f"Error: Server returned error {response.status_code}. ",file=sys.stderr)
         exit(1)
-    if (response.json() == [] ):
+    try:
+      if (response.json() == [] ):
+        return False
+    except:
+      print(f"There was an error parsing output from the mPCC.  Output: ")
+      print(f"{response.text}")
       return False
     # print(job_module)
     # print(response.json())
@@ -273,11 +280,13 @@ class JobServer ():
         'one_minute_load': os.getloadavg()[0]
     }
     # print(self.config_data)
-    if 'image-server' in self.config_data:
-    # if  self.config_data['image-server']:
-      if 'serverPort' in self.config_data['image-server']:
-        # print(self.config_data['image-server']['serverPort'])
-        data['port'] = self.config_data['image-server']['serverPort']
+    if 'mprov-webserver' in self.config_data:
+    # if  self.config_data['mprov-webserver']:
+      if 'serverPort' in self.config_data['mprov-webserver']:
+        # print(self.config_data['mprov-webserver']['serverPort'])
+        data['port'] = self.config_data['mprov-webserver']['serverPort']
+      else: 
+        data['port'] = 8080
     
     #print(data)
     # post the response (maybe should be put?) to the server.
